"""Autogenerated Python gRPC interface package for ansys-api-sherlock."""

import pathlib

__all__ = ["__version__"]

with open(pathlib.Path(__file__).parent / "VERSION", encoding="utf-8") as f:
    __version__ = f.read().strip()
